@@ -1,4 +1,4 @@
-use super::{Graph, Layout, PyGraph};
+use super::{FileFormat, Graph, Layout, PyGraph};
 use crate::{page_rank::PageRankResult, wcc::WccResult};
 use graph::{
     page_rank::PageRankConfig,
@@ -30,11 +30,16 @@ impl DiGraph {
 /// A directed graph using 32 bits for node ids.
 #[pymethods]
 impl DiGraph {
-    /// Load a graph in the Graph500 format
+    /// Load a graph in the provided format
     #[staticmethod]
-    #[args(layout = "None")]
-    pub fn load(py: Python<'_>, path: PathBuf, layout: Option<Layout>) -> PyResult<Self> {
-        let g = PyGraph::load(py, path, layout)?;
+    #[args(layout = "None", file_format = "FileFormat::Graph500")]
+    pub fn load(
+        py: Python<'_>,
+        path: PathBuf,
+        layout: Option<Layout>,
+        file_format: FileFormat,
+    ) -> PyResult<Self> {
+        let g = PyGraph::load_file(py, path, layout, file_format)?;
         Ok(Self::new(g.load_micros, g))
     }
 
